@@ -7,41 +7,39 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '0.09';
+our $VERSION = '1.00';
 
 # AUTHORITY
 
-our $AUTHORITY = 'cpan:CPANERY';
+our $AUTHORITY = 'cpan:AWNCORP';
 
 # IMPORTS
 
 sub import {
-  my ($package, @exports) = @_;
+  my ($self, @args) = @_;
 
   my $target = caller;
 
   no strict 'refs';
 
   my %seen;
-  for my $name (grep !$seen{$_}++, @exports, 'true', 'false') {
-    *{"${target}::${name}"} = $package->can($name) if !$target->can($name);
+  for my $name (grep !$seen{$_}++, @args, 'true', 'false') {
+    *{"${target}::${name}"} = $self->can($name) if !$target->can($name);
   }
 
-  return $package;
+  return $self;
 }
 
 # FUNCTIONS
 
 sub catch (&) {
-  my (@args) = @_;
-
-  my ($callback) = @_;
-
-  require Venus::Try;
+  my ($data) = @_;
 
   my $error;
 
-  my @result = Venus::Try->new($callback)->error(\$error)->result;
+  require Venus::Try;
+
+  my @result = Venus::Try->new($data)->error(\$error)->result;
 
   return wantarray ? ($error ? ($error, undef) : ($error, @result)) : $error;
 }
@@ -64,11 +62,9 @@ sub false () {
 }
 
 sub raise ($;$) {
-  my ($package, $data) = @_;
+  my ($self, $data) = @_;
 
-  my $parent = 'Venus::Error';
-
-  ($package, $parent) = (@$package) if (ref($package) eq 'ARRAY');
+  ($self, my $parent) = (@$self) if (ref($self) eq 'ARRAY');
 
   $data //= {};
   $data->{context} //= (caller(1))[3];
@@ -77,7 +73,7 @@ sub raise ($;$) {
 
   require Venus::Throw;
 
-  return Venus::Throw->new(package => $package, parent => $parent)->error($data);
+  return Venus::Throw->new(package => $self, parent => $parent)->error($data);
 }
 
 sub true () {
@@ -103,7 +99,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-0.09
+1.00
 
 =cut
 
@@ -140,14 +136,15 @@ OO Standard Library for Perl 5
 =head1 DESCRIPTION
 
 This library provides an object-orientation framework and extendible standard
-library for Perl 5, built on top of L<Moo> with classes which wrap most native
-Perl data types. Venus has a simple modular architecture, robust library of
-classes and methods, supports pure-Perl autoboxing, advanced exception
-handling, "true" and "false" keywords, package introspection, command-line
-options parsing, and more. This package will always automatically exports
-C<true> and C<false> keyword functions (unless existing routines of the same
-name already exist in the calling package), otherwise exports keyword functions
-as requested at import. This library requires Perl C<5.18+>.
+library for Perl 5, built on top of the L<Mars> architecture with classes which
+wrap most native Perl data types. Venus has a simple modular architecture,
+robust library of classes, methods, and roles, supports pure-Perl autoboxing,
+advanced exception handling, "true" and "false" functions, package
+introspection, command-line options parsing, and more. This package will always
+automatically exports C<true> and C<false> keyword functions (unless existing
+routines of the same name already exist in the calling package or its parents),
+otherwise exports keyword functions as requested at import. This library
+requires Perl C<5.18+>.
 
 =cut
 
@@ -177,7 +174,9 @@ I<Since C<0.01>>
 
   my $error = catch {die};
 
-  $error; # 'Died at ...'
+  $error;
+
+  # 'Died at ...'
 
 =back
 
@@ -191,7 +190,9 @@ I<Since C<0.01>>
 
   my ($error, $result) = catch {error};
 
-  $error; # Venus::Error
+  $error;
+
+  # Venus::Error
 
 =back
 
@@ -205,7 +206,9 @@ I<Since C<0.01>>
 
   my ($error, $result) = catch {true};
 
-  $result; # 1
+  $result;
+
+  # 1
 
 =back
 
@@ -230,6 +233,8 @@ I<Since C<0.01>>
 
   my $error = error;
 
+  # bless({...}, 'Venus::Error')
+
 =back
 
 =over 4
@@ -244,6 +249,8 @@ I<Since C<0.01>>
     message => 'Something failed!',
   };
 
+  # bless({message => 'Something failed!', ...}, 'Venus::Error')
+
 =back
 
 =cut
@@ -267,6 +274,8 @@ I<Since C<0.01>>
 
   my $false = false;
 
+  # 0
+
 =back
 
 =over 4
@@ -279,6 +288,8 @@ I<Since C<0.01>>
 
   my $true = !false;
 
+  # 1
+
 =back
 
 =cut
@@ -303,6 +314,8 @@ I<Since C<0.01>>
 
   my $error = raise 'MyApp::Error';
 
+  # bless({...}, 'MyApp::Error')
+
 =back
 
 =over 4
@@ -315,6 +328,8 @@ I<Since C<0.01>>
 
   my $error = raise ['MyApp::Error', 'Venus::Error'];
 
+  # bless({...}, 'MyApp::Error')
+
 =back
 
 =over 4
@@ -329,6 +344,8 @@ I<Since C<0.01>>
     message => 'Something failed!',
   };
 
+  # bless({message => 'Something failed!', ...}, 'MyApp::Error')
+
 =back
 
 =cut
@@ -352,6 +369,8 @@ I<Since C<0.01>>
 
   my $true = true;
 
+  # 1
+
 =back
 
 =over 4
@@ -364,6 +383,8 @@ I<Since C<0.01>>
 
   my $false = !true;
 
+  # 0
+
 =back
 
 =cut
@@ -413,6 +434,8 @@ B<example 1>
 
   $array->count == $hash->count;
 
+  # 1
+
 =back
 
 =over 4
@@ -430,6 +453,8 @@ B<example 1>
 
   my $array = Venus::Array->new;
 
+  # bless({...}, 'Venus::Array')
+
 B<example 2>
 
   package main;
@@ -438,6 +463,8 @@ B<example 2>
 
   my $boolean = Venus::Boolean->new;
 
+  # bless({...}, 'Venus::Boolean')
+
 B<example 3>
 
   package main;
@@ -446,6 +473,8 @@ B<example 3>
 
   my $code = Venus::Code->new;
 
+  # bless({...}, 'Venus::Code')
+
 B<example 4>
 
   package main;
@@ -454,6 +483,8 @@ B<example 4>
 
   my $float = Venus::Float->new;
 
+  # bless({...}, 'Venus::Float')
+
 B<example 5>
 
   package main;
@@ -462,6 +493,8 @@ B<example 5>
 
   my $hash = Venus::Hash->new;
 
+  # bless({...}, 'Venus::Hash')
+
 B<example 6>
 
   package main;
@@ -470,6 +503,8 @@ B<example 6>
 
   my $number = Venus::Number->new;
 
+  # bless({...}, 'Venus::Number')
+
 B<example 7>
 
   package main;
@@ -478,6 +513,8 @@ B<example 7>
 
   my $regexp = Venus::Regexp->new;
 
+  # bless({...}, 'Venus::Regexp')
+
 B<example 8>
 
   package main;
@@ -486,6 +523,8 @@ B<example 8>
 
   my $scalar = Venus::Scalar->new;
 
+  # bless({...}, 'Venus::Scalar')
+
 B<example 9>
 
   package main;
@@ -494,6 +533,8 @@ B<example 9>
 
   my $string = Venus::String->new;
 
+  # bless({...}, 'Venus::String')
+
 B<example 10>
 
   package main;
@@ -502,6 +543,8 @@ B<example 10>
 
   my $undef = Venus::Undef->new;
 
+  # bless({...}, 'Venus::Undef')
+
 =back
 
 =over 4
@@ -540,6 +583,8 @@ B<example 1>
 
   my $args = Venus::Args->new;
 
+  # bless({...}, 'Venus::Args')
+
 B<example 2>
 
   package main;
@@ -548,6 +593,8 @@ B<example 2>
 
   my $box = Venus::Box->new;
 
+  # bless({...}, 'Venus::Box')
+
 B<example 3>
 
   package main;
@@ -556,6 +603,8 @@ B<example 3>
 
   my $docs = Venus::Data->new->docs;
 
+  # bless({...}, 'Venus::Data')
+
 B<example 4>
 
   package main;
@@ -564,6 +613,8 @@ B<example 4>
 
   my $date = Venus::Date->new;
 
+  # bless({...}, 'Venus::Date')
+
 B<example 5>
 
   package main;
@@ -572,6 +623,8 @@ B<example 5>
 
   my $error = Venus::Error->new;
 
+  # bless({...}, 'Venus::Error')
+
 B<example 6>
 
   package main;
@@ -580,6 +633,8 @@ B<example 6>
 
   my $json = Venus::Json->new;
 
+  # bless({...}, 'Venus::Json')
+
 B<example 7>
 
   package main;
@@ -588,6 +643,8 @@ B<example 7>
 
   my $name = Venus::Name->new;
 
+  # bless({...}, 'Venus::Name')
+
 B<example 8>
 
   package main;
@@ -596,6 +653,8 @@ B<example 8>
 
   my $opts = Venus::Opts->new;
 
+  # bless({...}, 'Venus::Opts')
+
 B<example 9>
 
   package main;
@@ -604,6 +663,8 @@ B<example 9>
 
   my $path = Venus::Path->new;
 
+  # bless({...}, 'Venus::Path')
+
 B<example 10>
 
   package main;
@@ -612,6 +673,8 @@ B<example 10>
 
   my $text = Venus::Data->new->text;
 
+  # bless({...}, 'Venus::Data')
+
 B<example 11>
 
   package main;
@@ -620,6 +683,8 @@ B<example 11>
 
   my $space = Venus::Space->new;
 
+  # bless({...}, 'Venus::Space')
+
 B<example 12>
 
   package main;
@@ -628,6 +693,8 @@ B<example 12>
 
   my $throw = Venus::Throw->new;
 
+  # bless({...}, 'Venus::Throw')
+
 B<example 13>
 
   package main;
@@ -636,6 +703,8 @@ B<example 13>
 
   my $try = Venus::Try->new;
 
+  # bless({...}, 'Venus::Try')
+
 B<example 14>
 
   package main;
@@ -644,6 +713,8 @@ B<example 14>
 
   my $type = Venus::Type->new;
 
+  # bless({...}, 'Venus::Type')
+
 B<example 15>
 
   package main;
@@ -652,6 +723,8 @@ B<example 15>
 
   my $vars = Venus::Vars->new;
 
+  # bless({...}, 'Venus::Vars')
+
 B<example 16>
 
   package main;
@@ -660,6 +733,8 @@ B<example 16>
 
   my $match = Venus::Match->new;
 
+  # bless({...}, 'Venus::Match')
+
 B<example 17>
 
   package main;
@@ -668,6 +743,8 @@ B<example 17>
 
   my $process = Venus::Process->new;
 
+  # bless({...}, 'Venus::Process')
+
 B<example 18>
 
   package main;
@@ -676,6 +753,8 @@ B<example 18>
 
   my $template = Venus::Template->new;
 
+  # bless({...}, 'Venus::Template')
+
 B<example 19>
 
   package main;
@@ -684,6 +763,8 @@ B<example 19>
 
   my $yaml = Venus::Yaml->new;
 
+  # bless({...}, 'Venus::Yaml')
+
 =back
 
 =over 4
@@ -703,6 +784,8 @@ B<example 1>
 
   $space->do('tryload')->routines;
 
+  # [...]
+
 =back
 
 =over 4
@@ -733,7 +816,7 @@ B<example 1>
 
   my $error = $myapp->catch('execute');
 
-  # $error->isa('MyApp::Error');
+  # bless({...}, 'MyApp::Error');
 
 =back
 
@@ -797,6 +880,8 @@ B<example 1>
 
   $string->base64;
 
+  # "aGVsbG8sIHdvcmxk\n"
+
 =back
 
 =over 4
@@ -821,10 +906,12 @@ B<example 1>
 
   $template->render;
 
+  # "Welcome, friend!"
+
 =back
 
 =head1 AUTHORS
 
-Cpanery, C<cpanery@cpan.org>
+Awncorp, C<awncorp@cpan.org>
 
 =cut
\ No newline at end of file
