@@ -5,34 +5,12 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class 'base', 'with';
 
-extends 'Venus::Kind::Value';
+base 'Venus::Kind::Value';
 
 with 'Venus::Role::Mappable';
 
-# MODIFIERS
-
-around get => sub {
-  my ($orig, $self, @args) = @_;
-
-  return $self->$orig if $#_ < 2;
-
-  my ($index) = @args;
-
-  return $self->value->[$index];
-};
-
-around set => sub {
-  my ($orig, $self, @args) = @_;
-
-  return $self->$orig(@args) if $#_ < 3;
-
-  my ($index, $value) = @args;
-
-  return $self->value->[$index] = $value;
-};
-
 # METHODS
 
 sub all {
@@ -172,6 +150,16 @@ sub first {
   return $self->get->[0];
 }
 
+sub get {
+  my ($self, @args) = @_;
+
+  return $self->value if !int@args;
+
+  my ($index) = @args;
+
+  return $self->value->[$index];
+}
+
 sub grep {
   my ($self, $code) = @_;
 
@@ -404,6 +392,16 @@ sub rsort {
   return [CORE::sort { $b cmp $a } @$data];
 }
 
+sub set {
+  my ($self, @args) = @_;
+
+  return $self->value if !int@args;
+
+  my ($index, $value) = @args;
+
+  return $self->value->[$index] = $value;
+}
+
 sub shift {
   my ($self) = @_;
 
