@@ -5,22 +5,23 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use overload (
+  '""' => 'explain',
+  '~~' => 'explain',
+  fallback => 1,
+);
 
-extends 'Venus::Kind::Utility';
+use Venus::Class;
+
+base 'Venus::Kind::Utility';
 
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
 
 # ATTRIBUTES
 
-has decoder => (
-  is => 'rw',
-);
-
-has encoder => (
-  is => 'rw',
-);
+attr 'decoder';
+attr 'encoder';
 
 # BUILDERS
 
