@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class 'with';
 
 with 'Venus::Role::Boxable';
 with 'Venus::Role::Catchable';
@@ -138,7 +138,7 @@ Kind Base Class for Perl 5
 
   use Venus::Class;
 
-  extends 'Venus::Kind';
+  base 'Venus::Kind';
 
   package main;
 
@@ -213,9 +213,9 @@ I<Since C<0.08>>
 
   use Venus::Class;
 
-  extends 'Venus::Kind';
+  base 'Venus::Kind';
 
-  has 'value';
+  attr 'value';
 
   package main;
 
@@ -280,9 +280,9 @@ I<Since C<0.08>>
 
   use Venus::Class;
 
-  extends 'Venus::Kind';
+  base 'Venus::Kind';
 
-  has 'value';
+  attr 'value';
 
   package main;
 
@@ -403,9 +403,9 @@ I<Since C<0.08>>
 
   use Venus::Class;
 
-  extends 'Venus::Kind';
+  base 'Venus::Kind';
 
-  has 'value';
+  attr 'value';
 
   package main;
 
