@@ -5,9 +5,9 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class 'base', 'with';
 
-extends 'Venus::Kind';
+base 'Venus::Kind';
 
 with 'Venus::Role::Buildable';
 
@@ -33,7 +33,7 @@ Utility Base Class for Perl 5
 
   use Venus::Class;
 
-  extends 'Venus::Kind::Utility';
+  base 'Venus::Kind::Utility';
 
   package main;
 
