@@ -5,9 +5,15 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use overload (
+  '""' => 'explain',
+  '~~' => 'explain',
+  fallback => 1,
+);
 
-extends 'Venus::Kind';
+use Venus::Class;
+
+base 'Venus::Kind';
 
 with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
@@ -67,7 +73,7 @@ Value Base Class for Perl 5
 
   use Venus::Class;
 
-  extends 'Venus::Kind::Value';
+  base 'Venus::Kind::Value';
 
   package main;
 
