@@ -5,18 +5,21 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class 'base', 'with';
 
-extends 'Venus::Kind::Utility';
+base 'Venus::Kind::Utility';
 
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
 
 use overload (
+  '""' => 'explain',
   '.' => sub{$_[0]->value . "$_[1]"},
   'eq' => sub{$_[0]->value eq "$_[1]"},
   'ne' => sub{$_[0]->value ne "$_[1]"},
   'qr' => sub{qr/@{[quotemeta($_[0]->value)]}/},
+  '~~' => 'explain',
+  fallback => 1,
 );
 
 # METHODS
@@ -1882,4 +1885,36 @@ B<example 1>
 
   # 1
 
+=back
+
+=over 4
+
+=item operation: C<("")>
+
+This package overloads the C<""> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = "$path";
+
+  # "t/data/planets"
+
+=back
+
+=over 4
+
+=item operation: C<(~~)>
+
+This package overloads the C<~~> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = $path ~~ 't/data/planets';
+
+  # 1
+
 =back
\ No newline at end of file
