@@ -5,9 +5,15 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use overload (
+  '""' => 'explain',
+  '~~' => 'explain',
+  fallback => 1,
+);
 
-extends 'Venus::Kind::Utility';
+use Venus::Class;
+
+base 'Venus::Kind::Utility';
 
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
@@ -1196,4 +1202,42 @@ I<Since C<0.06>>
 
 =back
 
-=cut
\ No newline at end of file
+=cut
+
+=head1 OPERATORS
+
+This package overloads the following operators:
+
+=cut
+
+=over 4
+
+=item operation: C<("")>
+
+This package overloads the C<""> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = "$parent";
+
+  # $pid
+
+=back
+
+=over 4
+
+=item operation: C<(~~)>
+
+This package overloads the C<~~> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = $parent ~~ /^\d+$/;
+
+  # 1
+
+=back
\ No newline at end of file
