@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 with 'Venus::Role::Tryable';
 
@@ -19,6 +19,12 @@ sub catch {
   return wantarray ? ($error ? ($error, undef) : ($error, @result)) : $error;
 }
 
+# EXPORTS
+
+sub EXPORT {
+  ['catch', 'try']
+}
+
 1;
 
 
