@@ -5,7 +5,7 @@ use 5.014;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 with 'Venus::Role::Dumpable';
 
@@ -47,6 +47,12 @@ sub hexdigest {
   return $self->digester($algorithm, $method, @args)->hexdigest;
 }
 
+# EXPORTS
+
+sub EXPORT {
+  ['digester', 'digest', 'dump', 'dump_pretty', 'b64digest', 'bindigest', 'hexdigest']
+}
+
 1;
 
 
@@ -69,7 +75,7 @@ Digestable Role for Perl 5
 
   use Venus::Class;
 
-  has 'test';
+  attr 'test';
 
   with 'Venus::Role::Digestable';
 
