@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 # METHODS
 
@@ -19,6 +19,12 @@ sub match {
   return $match;
 }
 
+# EXPORTS
+
+sub EXPORT {
+  ['match']
+}
+
 1;
 
 
@@ -43,7 +49,7 @@ Matchable Role for Perl 5
 
   with 'Venus::Role::Matchable';
 
-  has 'active';
+  attr 'active';
 
   sub validate {
     my ($self) = @_;
