@@ -5,31 +5,31 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 with 'Venus::Role::Proxyable';
 
-# BUILDERS
+# METHODS
 
 sub build_proxy {
-  return undef;
-}
-
-# MODIFIERS
-
-around build_proxy => sub {
-  my ($orig, $self, $package, $method, @args) = @_;
+  my ($self, $package, $method, @args) = @_;
 
   require Venus::Space;
 
   my $space = Venus::Space->new($package)->child('plugin', $method);
 
-  return $self->$orig($package, $method, @args) if !$space->tryload;
+  return undef if !$space->tryload;
 
   return sub {
     return $space->build->execute($self, @args);
   };
-};
+}
+
+# EXPORTS
+
+sub EXPORT {
+  ['AUTOLOAD', 'BUILDPROXY', 'build_proxy']
+}
 
 1;
 
@@ -67,7 +67,7 @@ Pluggable Role for Perl 5
 
   with 'Venus::Role::Pluggable';
 
-  has 'secret';
+  attr 'secret';
 
   package main;
 
