@@ -5,31 +5,38 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class;
 
-extends 'Venus::Kind::Utility';
+base 'Venus::Kind::Utility';
 
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
 
 use overload (
+  '""' => 'explain',
   '.' => sub{$_[0]->render . "$_[1]"},
   'eq' => sub{$_[0]->render eq "$_[1]"},
   'ne' => sub{$_[0]->render ne "$_[1]"},
   'qr' => sub{qr/@{[quotemeta($_[0]->render)]}/},
+  '~~' => 'explain',
+  fallback => 1,
 );
 
 # ATTRIBUTES
 
-has markers => (
-  is => 'rw',
-  default => sub{[qr/\{\{/, qr/\}\}/]},
-);
+attr 'markers';
+attr 'variables';
 
-has variables => (
-  is => 'rw',
-  default => sub{{}},
-);
+# BUILDERS
+
+sub build_self {
+  my ($self, $data) = @_;
+
+  $self->markers([qr/\{\{/, qr/\}\}/]) if !defined $self->markers;
+  $self->variables({}) if !defined $self->variables;
+
+  return $self;
+}
 
 # METHODS
 
@@ -494,4 +501,42 @@ structurs with the appropriate replacements and returns the result.
 
 =back
 
-=cut
\ No newline at end of file
+=cut
+
+=head1 OPERATORS
+
+This package overloads the following operators:
+
+=cut
+
+=over 4
+
+=item operation: C<("")>
+
+This package overloads the C<""> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = "$template";
+
+  # "From: <>"
+
+=back
+
+=over 4
+
+=item operation: C<(~~)>
+
+This package overloads the C<~~> operator.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $result = $template ~~ 'From: <>';
+
+  # 1
+
+=back
\ No newline at end of file
