@@ -5,9 +5,9 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class 'base', 'with';
 
-extends 'Venus::Data';
+base 'Venus::Data';
 
 with 'Venus::Role::Buildable';
 
@@ -23,13 +23,12 @@ sub test {
   __PACKAGE__->new($_[0]);
 }
 
-# MODIFIERS
+# BUILDERS
 
-around build_self => sub {
-  my ($orig, $self, $data) = @_;
-
-  $self->$orig($data);
+sub build_self {
+  my ($self, $data) = @_;
 
+  $self->SUPER::build_self($data);
   for my $item (qw(name abstract tagline synopsis description)) {
     @{$self->find(undef, $item)} || $self->throw->error({
       message => "Test missing pod section =$item",
@@ -307,7 +306,7 @@ sub eval {
 
   local $@;
 
-  my @result = CORE::eval($perl);
+  my @result = CORE::eval(join("\n\n", "no warnings q(redefine);", $perl));
 
   die $@ if $@;
 
@@ -989,10 +988,8 @@ sub test_for_integrates {
 
   my $package = $self->data('name');
 
-  require Role::Tiny;
-
-  ok(Role::Tiny::does_role($package, $_), "$package does $_")
-    for split /\n/, $data;
+  ok($package->can('does'), "$package has does");
+  ok($package->does($_), "$package does $_") for split /\n/, $data;
 
   return $result;
 }
@@ -1468,6 +1465,13 @@ sub text_for_version {
     push @$output, $result;
   }
 
+  if (!@$output) {
+    my $name = $self->text_for_name;
+    if (my $version = ($name->[0] =~ m/([:\w]+)/m)[0]->VERSION) {
+      push @$output, $version;
+    }
+  }
+
   return $output;
 }
 
@@ -1603,6 +1607,8 @@ The for method attempts to find the POD content based on the name provided and
 executes the corresponding predefined test, optionally accepting a callback
 which, if provided, will be passes a L<Venus::Try> object containing the
 POD-driven test. The callback, if provided, must always return a true value.
+B<Note:> All automated tests disable the I<"redefine"> class of warnings to
+prevent warnings when redeclaring packages in examples.
 
 I<Since C<0.09>>
 
